SystemOrganization addCategory: #'DAO-Satellite'!

TestCase subclass: #CommandEncoderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!CommandEncoderTest methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/15/2013 19:25'!
testEncodingNameCommandRequestShouldReturnCorrectString
	"comment stating purpose of message"

	|nameCommandString encoder  nameCommand resultingByteArray |
	
	encoder := CommandEncoder new.
	nameCommand :=  GetNameCommand newWithReceiver: (SatelliteTest memorySubsystem) andId: 0. 
	resultingByteArray := encoder encodeWith: 'FFF' SequenceNumber: CommandSequenceNumber new andCommand: nameCommand.
	
	
	self assert: resultingByteArray equals:  #[70 70 70 0 0 1 0]! !

!CommandEncoderTest methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/15/2013 20:34'!
testEncodingSetMatrixKeyRequestShouldReturnCorrectString
	"comment stating purpose of message"

	|nameCommandString encoder  command resultingByteArray |
	
	encoder := CommandEncoder new.
	command :=  SetMatrixKeyCommand newWithReceiver: SatelliteTest thermalSubsystem andId: 32.
	command addParameters: 1.
	resultingByteArray := encoder encodeWith: 'FFF' SequenceNumber: CommandSequenceNumber new andCommand: command.
	
	
	self assert: resultingByteArray equals:  #[70 70 70 0 0 1 32 0 0 0 1]! !

!CommandEncoderTest methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/15/2013 21:35'!
testEncodingTelemetryRequestShouldReturnCorrectString
	"comment stating purpose of message"

	| encoder  nameCommand resultingByteArray |
	
	encoder := CommandEncoder new.
	nameCommand :=  GetTelemetryCommand newWithReceiver: (SatelliteTest memorySubsystem) andId: 1. 
	resultingByteArray := encoder encodeWith: 'FFF' SequenceNumber: CommandSequenceNumber new andCommand: nameCommand.
	
	
	self assert: resultingByteArray equals:  #[70 70 70 0 0 1 1]! !

TestCase subclass: #CommandInterpreterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!CommandInterpreterTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:04'!
commandInterpreter
	| satellite commandInterpreter |
	
	satellite := SatelliteTest satelliteWithThermalAndMemorySubsystems.
	commandInterpreter := satellite commandInterpreter.
	
	^ commandInterpreter.! !

!CommandInterpreterTest methodsFor: 'command' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:34'!
testWhenParsingNameCommandForSubsystemIdCommandIsReturned
	| satellite commandInterpreter command |
	
	"setup"
	satellite := SatelliteTest satelliteWithThermalAndMemorySubsystems.
	commandInterpreter := satellite commandInterpreter.
	
	"exercise"
	"subsystem 3 is THERMAL"
	command := commandInterpreter parseFromName: 'name' andSubsystemId: 3.
	
	"verify"
	self assert: (command receiver) equals: (SatelliteTest thermalSubsystem).
	self assert: (command class) equals: GetNameCommand.! !

!CommandInterpreterTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:38'!
testWhenReceivesSubsystemIdTheCorrespondingSubsytemIsResolved

	| commandInterpreter subsystem |
	
	commandInterpreter := self commandInterpreter.
	
	subsystem := commandInterpreter resolveSubsystem: 3.
	
	self assert: subsystem equals: (SatelliteTest thermalSubsystem).
! !

TestCase subclass: #CommandResponseDecoderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!CommandResponseDecoderTest methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/16/2013 20:48'!
testDecodingEncodedThermalNameResponseShouldReturnThermal

	| decoder encodedResponse decodedResponse |
	decoder := CommandResponseDecoder new.
	"001 sequence number, 7 long del string, lo que le sigue THERMAL codificado"
	encodedResponse := #[0 0 1 7 84 72 69 82 77 65 76].
	decodedResponse := decoder decode: encodedResponse.
	
	self assert: decodedResponse sequenceNumber equals: 1.
	self assert:  decodedResponse message equals: 'THERMAL'! !

!CommandResponseDecoderTest methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/16/2013 21:08'!
testDecodingEncodedThermalTelemetryResponseShouldReturnThermalTelemetry

	| decoder encodedResponse decodedResponse thermalTelemetryResponseStructure |
	decoder := CommandResponseDecoder new.
	"001 sequence number, 0 0 0 1 battery temp, 0 0 0 2 radio temp"
	encodedResponse := #[0 0 1 0 0 0 1 0 0 0 2].
	thermalTelemetryResponseStructure :=  OrderedCollection new: 2.
	thermalTelemetryResponseStructure add: 's16'.
	thermalTelemetryResponseStructure add: 's16'.
	
	decodedResponse := decoder decode: encodedResponse using: thermalTelemetryResponseStructure.
	
	self assert: decodedResponse sequenceNumber equals: 1.
	"TODO: use 'battery_temp' and 'radio_temp' as keys, instead of 1 and 2"
	self assert: (decodedResponse at: 1) equals: 1.
	self assert: (decodedResponse at: 2) equals: 2.
! !

TestCase subclass: #CommandSequenceNumberTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!CommandSequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 19:12'!
test1AsByteArray
	| sequenceNumber |

	sequenceNumber := CommandSequenceNumber new.

	self assert: sequenceNumber asByteArray equals: #[0 0 1].! !

!CommandSequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 19:10'!
testLastSequenceNumberAsByteArray
	| sequenceNumber lastNumber |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFF0' base: 16.

	sequenceNumber := CommandSequenceNumber newWithStart: lastNumber.

	self assert: sequenceNumber asByteArray equals: #[255 255 240].! !

!CommandSequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 15:22'!
testNewSequenceNumberStartsIn1
	| sequenceNumber |
	
	sequenceNumber := CommandSequenceNumber new.
	
	self assert: sequenceNumber number equals: 1! !

!CommandSequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 21:14'!
testNextOfLastNumberIs1
	| lastNumber sequenceNumber one |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFEF' base: 16.
	sequenceNumber := CommandSequenceNumber newWithStart: lastNumber.
	one := sequenceNumber next.
	
	self assert: one equals: 1! !

TestCase subclass: #CommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!CommandTest methodsFor: 'command' stamp: 'EzequielDavidovichCaballero 9/15/2013 17:43'!
testSendingNameCommandToThermalSubsystem
	| thermalSubsystem command response echoResponse |
	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	command := GetNameCommand newWithReceiver: thermalSubsystem andId: 0.
	echoResponse := MessageCommandResponse newWithMessage: 'THERMAL'.	"exercise"
	response := command execute.	"verify"
	self assert: response equals: echoResponse! !

!CommandTest methodsFor: 'command' stamp: 'EzequielDavidovichCaballero 9/15/2013 17:43'!
testSendingSetMatrixKeyCommandToThermalSubsystem
	| thermalSubsystem command response voidResponse |
	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	command := SetMatrixKeyCommand newWithReceiver: thermalSubsystem andId: 0.
	voidResponse := VoidCommandResponse new.	"exercise"
	response := command executeWithParameter: 10.	"verify"
	self assert: response equals: voidResponse.
	self assert: (thermalSubsystem getValueOfAttribute: 'matrix_key') equals: 10! !

!CommandTest methodsFor: 'command' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/16/2013 10:13'!
testSerializedReadLongAddressCommandShouldReturn9Bytes
	
	| command |
	
	command := ReadLongAddressCommand newWithReceiver: SatelliteTest memorySubsystem andId: 44.

	command addParameters: 1.
	command addParameters: 2.
	
	self assert: command serialize equals: #[44 0 0 0 1 0 0 0 2]! !

!CommandTest methodsFor: 'command' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/16/2013 10:05'!
testSerializedSetMatrixKeyCommandShouldReturn32andFourBits
	
	| command |
	
	command := SetMatrixKeyCommand newWithReceiver: SatelliteTest thermalSubsystem andId: 32.

	command addParameters: 1.
	
	self assert: command serialize equals: #[32 0 0 0 1]! !

TestCase subclass: #ControllerLogTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:13'!
testWhenAskingForASequenceNumberNotLoggedTheResultShouldBeFalse
	| log |
	
	log := ControllerLog new.
	
	self deny: (log containsEntryWithSequenceNumber: 1)
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:13'!
testWhenLoggingARequestTheSequenceNumberIsLogged
	| log |
	
	log := ControllerLog new.
	
	log addRequest: 'telemetry' withSequenceNumber: 1.
	
	self assert: (log containsEntryWithSequenceNumber: 1)
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:14'!
testWhenLoggingARequestUsingAnExistingSequenceNumberShouldArchiveTheOriginalRequest
	"log using a sequence number and then log again using the same sequence number, to make the log archive the first entry"
	| log newLogEntry logEntryForArchiving archivedLogEntry |
	
	"setup"
	log := ControllerLog new.
	log addRequest: 'messageMovedToTheArchive' withSequenceNumber: 1.
	self assert: (log containsEntryWithSequenceNumber: 1).
	logEntryForArchiving := log entryWithSequenceNumber: 1.
	
	"exercise"
	"this should archive the first entry"
	log addRequest: 'expectedMessage' withSequenceNumber: 1.
	
	"verify"
	newLogEntry := log entryWithSequenceNumber: 1.
	self assert: (newLogEntry request) equals: 'expectedMessage'.
	archivedLogEntry := log archive at: 1.
	self assert: archivedLogEntry equals: logEntryForArchiving.

! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:14'!
testWhenLoggingAResponseUsingAnExistingSequenceNumberTheLogEntryShouldContainTheRequestAndTheResponse
	| log logEntry |
	
	"setup"
	log := ControllerLog new.
	log addRequest: 'requestMessage' withSequenceNumber: 1.
		
	"exercise"
	log addResponse: 'responseMessage' withSequenceNumber: 1.
	
	"verify"
	logEntry := log entryWithSequenceNumber: 1.
	self assert: (logEntry request) equals: 'requestMessage'.
	self assert: (logEntry response) equals: 'responseMessage'.
! !

TestCase subclass: #SatelliteIntegerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!SatelliteIntegerTest methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/15/2013 16:31'!
test01ThreeZeroBytesShouldRepresentZero

self assert: (LargePositiveInteger readFrom: '000000' base: 16) equals: 0.! !

TestCase subclass: #SatelliteSubsystemTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:23'!
testWhenCreatingASubsystemItCanAnswerBasicCommands

	| subsystem |

	"setup"
	subsystem := SatelliteTest memorySubsystem.

	"verify"	
	self assert: (subsystem understands: GetNameCommand).
	self assert: (subsystem understands: GetTelemetryCommand).
	self assert: (subsystem understands: GetShortTelemetryCommand).
! !

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:24'!
testWhenCreatingASubsystemItDoesntUnderstandUnknwonCommand

	| subsystem notACommand |

	"setup"
	subsystem := SatelliteTest memorySubsystem.
	notACommand := Object new.

	"verify"	
	self deny: (subsystem understands: notACommand).
! !

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 19:15'!
testWhenCreatingASubsystemTheIdAndNameIsSet

	| subsystem |

	"setup"
	subsystem := MemorySatelliteSubsystem newWithId: 1 andName: 'MEMORY'.

	"verify"	
	self assert: subsystem id equals: 1.
	self assert: subsystem name equals: 'MEMORY'.
! !

TestCase subclass: #SatelliteTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:53'!
memorySubsystem
	| memorySubsystem |

	memorySubsystem := MemorySatelliteSubsystem newWithId: 1 andName: 'MEMORY'.
	memorySubsystem setAttribute: 'free' withValue: 100.
	
	^ memorySubsystem! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:54'!
satelliteWithThermalAndMemorySubsystems
	| subsystems |

	subsystems := Set new.	
	subsystems add: self memorySubsystem.
	subsystems add: self thermalSubsystem.

	^ Satellite newWithSubsystems: subsystems.
! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:53'!
thermalSubsystem
	| thermalSubsystem |

	thermalSubsystem := ThermalSatelliteSubsystem newWithId: 3 andName: 'THERMAL'.
	thermalSubsystem setAttribute: 'battery_temp' withValue: 10.
	thermalSubsystem setAttribute: 'radio_temp' withValue: 20.
	
	^ thermalSubsystem! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:27'!
testGivenASatelliteWhenEmittingAShortBeaconItReturnsAShortBeacon

	| satellite subsystems thermalSubsystem expectedBeacon beacon |

	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	thermalSubsystem setAttribute: 'battery_temp' withValue: '10'.
	thermalSubsystem setAttribute: 'radio_temp' withValue: '20'.
	subsystems := Set new.
	subsystems add: thermalSubsystem.
	satellite := Satellite newWithSubsystems: subsystems.
	expectedBeacon := '{"short_telemetry":[{"subsystem_id":"3","battery_temp":"10"}]}'.

	"exercise"	
	beacon := satellite emitShortBeacon.

	"verify"	
	self assert: beacon equals: expectedBeacon.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 12:46'!
testGivenASatelliteWithThermalSubsystemOnlyWhenEmittingABeaconTheBeaconContainsOnlyThermalTelemetry

	| satellite subsystems thermalSubsystem expectedBeacon beacon |

	"setup"
	thermalSubsystem := ThermalSatelliteSubsystem newWithId: 3 andName: 'THERMAL'.
	thermalSubsystem setAttribute: 'battery_temp' withValue: '10'.
	thermalSubsystem setAttribute: 'radio_temp' withValue: '20'.
	subsystems := Set new.
	subsystems add: thermalSubsystem.
	satellite := Satellite newWithSubsystems: subsystems.
	expectedBeacon := '{"telemetry":[{"subsystem_id":"3","battery_temp":"10","radio_temp":"20"}]}'.

	"exercise"	
	beacon := satellite emitBeacon.

	"verify"	
	self assert: beacon equals: expectedBeacon.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:15'!
testGivenASatelliteWithTwoSubsystemsWhenEmittingABeaconTheBeaconContainsTwoTelemetryData

	| satellite expectedBeacon beacon |

	"setup"
	satellite := SatelliteTest satelliteWithThermalAndMemorySubsystems.

	expectedBeacon := '{"telemetry":[{"subsystem_id":"1","free":"100"},{"subsystem_id":"3","battery_temp":"10","radio_temp":"20"}]}'.

	"exercise"	
	beacon := satellite emitBeacon.

	"verify"	
	self assert: beacon equals: expectedBeacon.
! !

Object subclass: #CommandEncoder
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!CommandEncoder methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/15/2013 20:35'!
encodeWith: aMAC SequenceNumber: aSequenceNumber andCommand: aCommand
	| encodedBytes encodedCommand|
	
	encodedCommand := aCommand serialize.
	
	encodedBytes := ByteArray new: 6 + (encodedCommand size).

	
	encodedBytes := encodedBytes replaceFrom: 1 to: 3  with:  aMAC.
	
	encodedBytes := encodedBytes replaceFrom: 4 to: 6  with:  (aSequenceNumber asByteArray).
	
	encodedBytes := encodedBytes replaceFrom: 7 to: (encodedBytes size) with:  (encodedCommand).
	
	
	^ encodedBytes.! !

Object subclass: #CommandInterpreter
	instanceVariableNames: 'subsystems commandClasses'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!CommandInterpreter class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:14'!
newWithSubsystems: theSubsystems
	^ self new initializeWithSubystems: theSubsystems.! !

!CommandInterpreter methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:14'!
initializeWithSubystems: theSubsystems
	subsystems := Dictionary new.
	theSubsystems do: [ :subsystem | subsystems at: (subsystem id) put: subsystem].
	
	commandClasses := Dictionary new.
	commandClasses at: 'name' put: GetNameCommand.
	commandClasses at: 'telemetry' put: GetTelemetryCommand.
	commandClasses at: 'short_telemetry' put: GetShortTelemetryCommand.
	commandClasses at: 'setMatrixKey' put: SetMatrixKeyCommand.! !

!CommandInterpreter methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/15/2013 17:43'!
parseFromName: aCommandName andSubsystemId: aSubsystemId
	| subsystem commandClass command |
	subsystem := self resolveSubsystem: aSubsystemId.
	commandClass := commandClasses at: aCommandName.
	command := commandClass newWithReceiver: subsystem andId: 0.
	^ command! !

!CommandInterpreter methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:10'!
resolveSubsystem: aKey 
	^ subsystems at: aKey.! !

Object subclass: #CommandResponse
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

CommandResponse subclass: #MessageCommandResponse
	instanceVariableNames: 'message sequenceNumber contents'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!MessageCommandResponse class methodsFor: 'class initialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 21:06'!
newWithMessage: aMessage 
	self new initializeWithMessage: aMessage.! !

!MessageCommandResponse class methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/17/2013 18:10'!
newWithSequenceNumber: aSequenceNumber andContents: anOrderedCollection 

	^self new initializeWith: aSequenceNumber andContents: anOrderedCollection ! !

!MessageCommandResponse class methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/16/2013 20:32'!
newWithSequenceNumber: aSequenceNumber andMessage: aMessage 
	^ self new initializeWith: aSequenceNumber and: aMessage! !

!MessageCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 21:01'!
= anObject
	^ message = anObject message
! !

!MessageCommandResponse methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/17/2013 18:12'!
at: aSmallInteger

	^ contents at: aSmallInteger ! !

!MessageCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 21:02'!
initialize
	message = ''
! !

!MessageCommandResponse methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/16/2013 20:33'!
initializeWith: aSequenceNumber and: aMessage 
	sequenceNumber := aSequenceNumber.
	message := aMessage.! !

!MessageCommandResponse methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/17/2013 18:11'!
initializeWith: aSequenceNumber andContents: anOrderedCollection 
		sequenceNumber := aSequenceNumber.
		contents := anOrderedCollection.! !

!MessageCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 21:06'!
initializeWithMessage: aMessage 
	message := aMessage.! !

!MessageCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 21:02'!
message
	^ message
! !

!MessageCommandResponse methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/16/2013 20:34'!
sequenceNumber

	^ sequenceNumber! !

CommandResponse subclass: #VoidCommandResponse
	instanceVariableNames: 'code'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!VoidCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 20:58'!
= anotherResponse
	"TODO reemplazar con una sola instancia global de VoidCommandResponse"
	^ code = anotherResponse code ! !

!VoidCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 20:58'!
code
	^ code! !

!VoidCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 20:56'!
initialize
	code = -1
! !

Object subclass: #CommandResponseDecoder
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!CommandResponseDecoder methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/16/2013 20:30'!
decode: anEncodedResponse 
	| readStream sequenceNumber message messageLength |
	
	sequenceNumber := ByteArray new: 3.
	readStream := ReadStream on: anEncodedResponse.
	readStream readInto: sequenceNumber startingAt: 1 count: 3. "obteniendo nro de secuencia"
	
	messageLength := readStream next asInteger.
	message := ByteArray new: messageLength.
	readStream readInto: message startingAt: 1  count: messageLength.
	
	
	^ MessageCommandResponse newWithSequenceNumber: (sequenceNumber asInteger) andMessage: (message asString).
! !

!CommandResponseDecoder methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/17/2013 22:58'!
decode: anEncodedResponse using: typeKeys
"type sabe su longitud, el decode sabe leer el subarray segn la longitud del type y el signo"

	| response batteryTemp radioTemp sequenceNumber readStream |

	sequenceNumber := ByteArray new: 3.
	readStream := ReadStream on: anEncodedResponse.
	readStream readInto: sequenceNumber startingAt: 1 count: 3. "obteniendo nro de secuencia"
	
	batteryTemp := ByteArray new: 4.
	radioTemp := ByteArray new: 4.
	
	readStream readInto: batteryTemp startingAt: 1 count: 4.
	readStream readInto: radioTemp startingAt: 1 count: 4.
	response := OrderedCollection new: 2.
	response add: (batteryTemp asInteger).
	response add: radioTemp asInteger.	
	"
	typeKeys do: [ :typeKey |
		| type value |.
		type := self getType: typeKey. 
		value := type decode: subArray.
		result add: value.
		].
	"
	
	^ MessageCommandResponse newWithSequenceNumber: (sequenceNumber asInteger) andContents: response! !

!CommandResponseDecoder methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/16/2013 20:58'!
decodeStruct: aByteArray 
	self shouldBeImplemented.! !

!CommandResponseDecoder methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/17/2013 17:21'!
getType: aType 
	aType perform: #new.! !

Object subclass: #CommandSequenceNumber
	instanceVariableNames: 'number lastNumber'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

CommandSequenceNumber class
	instanceVariableNames: 'number'!

CommandSequenceNumber class
	instanceVariableNames: 'number'!

!CommandSequenceNumber class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 14:57'!
newWithStart: aNumber
	^ self new initializeWithStart: aNumber! !

!CommandSequenceNumber methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 19:08'!
asByteArray
	| resultSize resultBytes sequenceNumber start |

	resultSize := 3.

	resultBytes := ByteArray new: resultSize.
	
	sequenceNumber := number asByteArray.

	start := (resultSize - (sequenceNumber size) + 1).

	^ resultBytes replaceFrom: start to: resultSize with: sequenceNumber. 
! !

!CommandSequenceNumber methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 21:14'!
initialize
	number := 1.
	lastNumber := LargePositiveInteger readFrom: 'FFFFEF' base: 16.
! !

!CommandSequenceNumber methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 14:58'!
initializeWithStart: aNumber
	self initialize.
	number := aNumber.! !

!CommandSequenceNumber methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 14:53'!
next
	number := number + 1.
	number > lastNumber ifTrue: [ self reset. ].
	^ number.
! !

!CommandSequenceNumber methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 15:00'!
number
	^ number! !

!CommandSequenceNumber methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 14:52'!
reset
	number := 1.! !

Object subclass: #ControllerLog
	instanceVariableNames: 'entries archive'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!ControllerLog class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 20:13'!
newWithArchive: aLogArchive 
	^ self new initializeWithArchive: aLogArchive.! !

!ControllerLog methodsFor: 'recording' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 22:51'!
addRequest: aRequest withSequenceNumber: aSequenceNumber
	| entry |

	(self containsEntryWithSequenceNumber: aSequenceNumber) ifTrue: [
		entry := self entryWithSequenceNumber: aSequenceNumber.
		self archive: entry. ].
	
	entry := ControllerLogEntry newWithRequest: aRequest andSequenceNumber: aSequenceNumber.
	
	entries at: aSequenceNumber put: entry.
! !

!ControllerLog methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 22:21'!
addResponse: aResponse withSequenceNumber: aSequenceNumber
	| logEntry |

	logEntry := entries at: aSequenceNumber.

	logEntry setResponse: aResponse.
	! !

!ControllerLog methodsFor: 'recording' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:12'!
archive
	^ archive! !

!ControllerLog methodsFor: 'recording' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:12'!
archive: anEntry
	archive add: anEntry.! !

!ControllerLog methodsFor: 'accessing' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 22:51'!
containsEntryWithSequenceNumber: aNumber 
	[entries at: aNumber] on: KeyNotFound do: [ ^ false ].
	^ true.! !

!ControllerLog methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 20:15'!
entryWithSequenceNumber: aSequenceNumber 
	^ entries at: aSequenceNumber.! !

!ControllerLog methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:12'!
initialize
	entries := Dictionary new.
	archive := LinkedList new.! !

Object subclass: #ControllerLogEntry
	instanceVariableNames: 'sequenceNumber request time response'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

ControllerLogEntry class
	instanceVariableNames: 'time sequenceNumber request'!

ControllerLogEntry class
	instanceVariableNames: 'time sequenceNumber request'!

!ControllerLogEntry class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 20:46'!
newWithRequest: aRequest andSequenceNumber: aSequenceNumber
	^ self new initializeWithRequest: aRequest andSequenceNumber: aSequenceNumber.! !

!ControllerLogEntry methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 20:34'!
initializeWithRequest: aRequest andSequenceNumber: aSequenceNumber
	time := DateAndTime now.
	request := aRequest.
	sequenceNumber := aSequenceNumber.! !

!ControllerLogEntry methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 20:42'!
request
	^ request
! !

!ControllerLogEntry methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 22:20'!
response
	^ response! !

!ControllerLogEntry methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 22:21'!
setResponse: aResponse
	response := aResponse.! !

!ControllerLogEntry methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 20:35'!
time
	^ time! !

Object subclass: #Satellite
	instanceVariableNames: 'subsystems commandInterpreter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!Satellite class methodsFor: 'instance creation' stamp: 'EmilianoMenendez 9/7/2013 16:27'!
newWithSubsystems: theSubsystems 
	^ self new initalizeWithSubsystems: theSubsystems! !

!Satellite methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:54'!
commandInterpreter
	^ commandInterpreter! !

!Satellite methodsFor: 'signaling' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 19:48'!
emitBeacon
	| result outputStream telemetryDataOrderedBySubsystemId |
	
	outputStream := WriteStream on: String new.
	
	outputStream nextPutAll: '{"telemetry":['.
	
	telemetryDataOrderedBySubsystemId := OrderedIdentityDictionary new.
	
	subsystems do: [ :subsystem | telemetryDataOrderedBySubsystemId at: (subsystem id) put: subsystem telemetry].
	
	telemetryDataOrderedBySubsystemId do: [ :telemetry | outputStream nextPutAll: telemetry. outputStream nextPutAll: ',' ].
	
	result := outputStream contents.
	
	result := result truncateTo: ((result size) - 1).
	
	result := result , ']}'.
	
	^ result.
! !

!Satellite methodsFor: 'signaling' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 21:06'!
emitShortBeacon
	| result outputStream telemetryDataOrderedBySubsystemId |
	
	outputStream := WriteStream on: String new.
	
	outputStream nextPutAll: '{"short_telemetry":['.
	
	telemetryDataOrderedBySubsystemId := OrderedIdentityDictionary new.
	
	subsystems do: [ :subsystem | telemetryDataOrderedBySubsystemId at: (subsystem id) put: subsystem shortTelemetry].
	
	telemetryDataOrderedBySubsystemId do: [ :telemetry | outputStream nextPutAll: telemetry. outputStream nextPutAll: ',' ].
	
	result := outputStream contents.
	
	result := result truncateTo: ((result size) - 1).
	
	result := result , ']}'.
	
	^ result.
! !

!Satellite methodsFor: 'initialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:32'!
initalizeWithSubsystems: theSubsystems

	subsystems := theSubsystems.
	
	commandInterpreter := CommandInterpreter newWithSubsystems: subsystems.


! !

!Satellite methodsFor: 'accessing' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 19:59'!
subsystems
	
	^ subsystems
! !

Object subclass: #SatelliteCommand
	instanceVariableNames: 'receiver id parameters parameterSizes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

SatelliteCommand subclass: #GetNameCommand
	instanceVariableNames: 'receiver'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!GetNameCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:12'!
execute
	^ MessageCommandResponse newWithMessage: (receiver name)! !

SatelliteCommand subclass: #GetShortTelemetryCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

SatelliteCommand subclass: #GetTelemetryCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

SatelliteCommand subclass: #ReadLongAddressCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!ReadLongAddressCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/16/2013 10:10'!
initializeCommandDefinition
	parameterSizes := OrderedCollection new.
	parameterSizes add: 4.
	parameterSizes add: 4.

! !

!SatelliteCommand class methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/15/2013 20:28'!
newWithReceiver: aReceiver andId: anId
	^ self new initializeWithReceiver: aReceiver andId: anId ! !

!SatelliteCommand class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/16/2013 10:00'!
newWithReceiver: aReceiver andId: anId andParameterSizes: aList
	^ self new initializeWithReceiver: aReceiver andId: anId andParameterSizes: aList! !

!SatelliteCommand methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/15/2013 19:42'!
addParameters: anObject 
	parameters add: anObject! !

!SatelliteCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:11'!
execute
	^ self subclassResponsibility.! !

!SatelliteCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:12'!
executeWithParameter: parameter
	^ self subclassResponsibility.! !

!SatelliteCommand methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/15/2013 17:46'!
id
	^ id! !

!SatelliteCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/16/2013 10:58'!
initializeCommandDefinition
	"this should implemented by commands that receives parameters"
	parameterSizes := OrderedCollection new.! !

!SatelliteCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/16/2013 10:05'!
initializeWithReceiver: aReceiver andId: anId

	receiver := aReceiver.
	id := anId.
	parameters:= OrderedCollection new.
	self initializeCommandDefinition.! !

!SatelliteCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:13'!
receiver
	^ receiver! !

!SatelliteCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/16/2013 10:56'!
serialize
	
	| parameterSerialized serializedCommand start stop |
	
	parameterSerialized:= self serializeParameters.
	serializedCommand := ByteArray new: 1 + parameterSerialized size.
	start := 2.
	stop := serializedCommand size.
	
	serializedCommand at: 1 put: (id asByte).

	^ serializedCommand replaceFrom: start to: stop with: parameterSerialized. ! !

!SatelliteCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/16/2013 10:55'!
serializeParameters
	| parameterValue j k serializedParameters resultSize result |

	serializedParameters := OrderedCollection new.

	resultSize := 0.

	(1 to: (parameters size)) do: [ :i |
		parameterValue := parameters at: i.
		serializedParameters add: (parameterValue asByteArray).
		resultSize := resultSize + (parameterSizes at: i).
	].
	
	result := ByteArray new: resultSize.
	
	j := 0.

	(1 to: (parameters size)) do: [ :i |
		| serializedParameter |
		serializedParameter := serializedParameters at: i.
		j := j + parameterSizes at: i.
		k := j - (serializedParameter size) + 1.
		result replaceFrom: j to: k with: serializedParameter.
	].
	
	^ result.
! !

SatelliteCommand subclass: #SetMatrixKeyCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!SetMatrixKeyCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:12'!
executeWithParameter: parameter
	receiver setMatrixKey: parameter.
	
	^ VoidCommandResponse new.
	! !

!SetMatrixKeyCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/16/2013 10:07'!
initializeCommandDefinition
	parameterSizes := OrderedCollection new.
	parameterSizes add: 4.

! !

Object subclass: #SatelliteSubsystem
	instanceVariableNames: 'id data telemetryKeys shortTelemetryKeys name commands'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

SatelliteSubsystem subclass: #MemorySatelliteSubsystem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!MemorySatelliteSubsystem class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 16:00'!
newWithId: theId andName: theName
	| subsystem telemetryKeys shortTelemetryKeys |
	
	telemetryKeys := Set new.
	telemetryKeys add: 'free'.
	
	shortTelemetryKeys := Set new.
	shortTelemetryKeys add: 'free'.
	
	subsystem := self new initializeWithId: theId andName: theName andTelemetryKeys: telemetryKeys andShortTelemetryKeys: shortTelemetryKeys.
	
	^ subsystem.! !

!SatelliteSubsystem class methodsFor: 'accessing' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:26'!
basicCommands
	| commands |
	
	commands := Set new.

	commands add: GetNameCommand.
	commands add: GetTelemetryCommand.
	commands add: GetShortTelemetryCommand.

	^ commands! !

!SatelliteSubsystem class methodsFor: 'creation' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 18:58'!
newWithId: theId andName: theName
	^ self new initializeWithId: theId andName: theName andTelemetryKeys: Set new andShortTelemetryKeys: Set new! !

!SatelliteSubsystem methodsFor: 'command' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:35'!
= anObject
	^ id = anObject id! !

!SatelliteSubsystem methodsFor: 'accessing' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 18:27'!
commands
	^ commands! !

!SatelliteSubsystem methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:03'!
getValueOfAttribute: aKey
	^ (data at: aKey)! !

!SatelliteSubsystem methodsFor: 'accessing' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 16:10'!
id
	^ id! !

!SatelliteSubsystem methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 20:26'!
initializeWithId: theId andName: theName andTelemetryKeys: theTelemetryKeys andShortTelemetryKeys: theShortTelemetryKeys
	id := theId.
	name := theName.
	commands := SatelliteSubsystem basicCommands.
	telemetryKeys := theTelemetryKeys.
	shortTelemetryKeys := theShortTelemetryKeys.
	data := Dictionary new.! !

!SatelliteSubsystem methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 19:37'!
initializeWithId: theId andName: theName andTelemetryKeys: theTelemetryKeys andShortTelemetryKeys: theShortTelemetryKeys andCommands: theCommands
	id := theId.
	name := theName.
	commands := SatelliteSubsystem basicCommands.
	commands add: theCommands.
	telemetryKeys := theTelemetryKeys.
	shortTelemetryKeys := theShortTelemetryKeys.
	data := Dictionary new.! !

!SatelliteSubsystem methodsFor: 'command' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 16:11'!
name
	^ name! !

!SatelliteSubsystem methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 12:46'!
setAttribute: aKey withValue: aValue 
	data at: aKey put: aValue! !

!SatelliteSubsystem methodsFor: 'command' stamp: 'EmilianoMenendez 9/9/2013 10:26'!
shortTelemetry
	| result temp |
	
	temp := WriteStream on: String new.
	
	temp nextPutAll: '{'.
	
	"add subsytem_id"
	temp nextPutAll: '"subsystem_id":"'.
	temp nextPutAll: id asString.
	temp nextPutAll: '",'.
	
	"build key:value,key:value,,, string "
	data associationsDo: [ :entry | (shortTelemetryKeys includes: (entry key)) ifTrue: [temp nextPutAll: '"'. temp nextPutAll: (entry key asString) . temp nextPutAll: '":"'. temp nextPutAll: (entry value asString). temp nextPutAll: '",'.]].
	
	"send stream to string"
	result := temp contents.
	
	"remove last ,"
	result := result truncateTo: ((result size) - 1).
	
	result := result , '}'.
	
	^ result
! !

!SatelliteSubsystem methodsFor: 'command' stamp: 'EmilianoMenendez 9/8/2013 20:40'!
telemetry
	| result temp |
	
	temp := WriteStream on: String new.
	
	temp nextPutAll: '{'.
	
	"add subsytem_id"
	temp nextPutAll: '"subsystem_id":"'.
	temp nextPutAll: id asString.
	temp nextPutAll: '",'.
	
	"build key:value,key:value,,, string "
	data associationsDo: [ :entry | temp nextPutAll: '"'. temp nextPutAll: (entry key asString) . temp nextPutAll: '":"'. temp nextPutAll: (entry value asString). temp nextPutAll: '",'.].
	
	"send stream to string"
	result := temp contents.
	
	"remove last ,"
	result := result truncateTo: ((result size) - 1).
	
	result := result , '}'.
	
	^ result
! !

!SatelliteSubsystem methodsFor: 'accessing' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:22'!
understands: aCommandClass
	^ (commands includes: aCommandClass).! !

SatelliteSubsystem subclass: #ThermalSatelliteSubsystem
	instanceVariableNames: 'matrixKey'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!ThermalSatelliteSubsystem class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:13'!
newWithId: theId andName: theName
	| subsystem telemetryKeys shortTelemetryKeys matrixKeyCommand matrixKeyCommandEntry |
	
	telemetryKeys := Set new.
	telemetryKeys add: 'battery_temp'.
	telemetryKeys add: 'radio_temp'.
	
	shortTelemetryKeys := Set new.
	shortTelemetryKeys add: 'battery_temp'.
	
	matrixKeyCommand := SetMatrixKeyCommand new.
	matrixKeyCommandEntry := Association key: 'setMatrixKey' value: matrixKeyCommand.
	
	subsystem := self new initializeWithId: theId andName: theName andTelemetryKeys: telemetryKeys andShortTelemetryKeys: shortTelemetryKeys andCommands: matrixKeyCommandEntry.
	
	^ subsystem.! !

!ThermalSatelliteSubsystem methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:07'!
setMatrixKey: theValue
	data at: 'matrix_key' put: theValue! !

Object subclass: #SignedInteger
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!
